Received: from malur.postgresql.org ([2a02:16a8:dc51::56]) by arkaria.postgresql.org with esmtps (TLS1.2:ECDHE_RSA_AES_256_CBC_SHA384:256) (Exim 4.89) (envelope-from ) id 1fsjoP-0000mu-S9 for pgsql-hackers@arkaria.postgresql.org; Thu, 23 Aug 2018 07:13:46 +0000 Received: from localhost ([127.0.0.1] helo=malur.postgresql.org) by malur.postgresql.org with esmtp (Exim 4.89) (envelope-from ) id 1fsjoN-0002cR-M7 for pgsql-hackers@arkaria.postgresql.org; Thu, 23 Aug 2018 07:13:43 +0000 Received: from makus.postgresql.org ([2001:4800:1501:1::229]) by malur.postgresql.org with esmtps (TLS1.2:ECDHE_RSA_AES_256_CBC_SHA384:256) (Exim 4.89) (envelope-from ) id 1fsjoN-0002as-7s for pgsql-hackers@lists.postgresql.org; Thu, 23 Aug 2018 07:13:43 +0000 Received: from post.visena.com ([46.226.10.50]) by makus.postgresql.org with esmtps (TLS1.2:DHE_RSA_AES_256_CBC_SHA1:256) (Exim 4.89) (envelope-from ) id 1fsjoK-0008QG-ML for pgsql-hackers@lists.postgresql.org; Thu, 23 Aug 2018 07:13:42 +0000 DKIM-Signature: v=1; a=rsa-sha256; q=dns/txt; c=relaxed/relaxed; d=visena.com; s=20141101.wh; h=Content-Type:MIME-Version:Subject:In-Reply-To:Message-ID:Cc:To:From:Date; bh=vECbC0lY+xQKwgeHNXOePUJEhaIFTZEDBEzKeu9DjHc=; b=KlynpkHr55pER1n/Zmzp96kJZJ+oL4osCxs0FR23bidDjE3QIPyAPWNGQJ3s1r5oi4P9BwqDFGlvI9WLV3jh05FSTFYjd2kHbIIdimGLfgccH4e3ecTxlqXazsUeI4ThTZlwwKkB4H64gDRPXXwMgK2YAcpdjiJEbodRdrt7vbY=; Received: from [10.0.1.10] (helo=tc7-visena.wh.internal.visena.com) by post.visena.com with esmtp (Exim 4.82) (envelope-from ) id 1fsjoB-0002za-3b; Thu, 23 Aug 2018 09:13:32 +0200 Received: from localhost ([127.0.0.1] helo=tc7-visena.wh.internal.visena.com) by tc7-visena.wh.internal.visena.com with esmtp (Exim 4.86_2) (envelope-from ) id 1fsjpY-0003GD-8s; Thu, 23 Aug 2018 09:14:56 +0200 Date: Thu, 23 Aug 2018 09:14:56 +0200 (CEST) From: Andreas Joseph Krogh To: "Jonathan S. Katz" Cc: Andres Freund , Robert Haas , Alvaro Herrera , PostgreSQL Hackers Message-ID: In-Reply-To: <7884E7AD-2C41-496E-9829-66B79385DFC7@postgresql.org> Subject: Re: Query is over 2x slower with jit=on MIME-Version: 1.0 Content-Type: multipart/mixed; boundary="----=_Part_10_652420533.1535008496189" X-Mailer: Visena Mail 2.1.104 X-Spam-Score: -1.0 X-Spam-Report: SpamAssasin (score=-1.0, required 5.0 ALL_TRUSTED=-1,HTML_MESSAGE=0.001) List-Id: List-Help: List-Subscribe: List-Post: List-Owner: List-Archive: Precedence: bulk ------=_Part_10_652420533.1535008496189 Content-Type: multipart/related; boundary="----=_Part_11_729917402.1535008496189" ------=_Part_11_729917402.1535008496189 Content-Type: multipart/alternative; boundary="----=_Part_12_655446660.1535008496201" ------=_Part_12_655446660.1535008496201 Content-Type: text/plain; charset=UTF-8 Content-Transfer-Encoding: quoted-printable P=C3=A5 torsdag 23. august 2018 kl. 03:00:42, skrev Jonathan S. Katz < jkatz@postgresql.org >: > On Aug 22, 2018, at 7:13 PM, Andres Freund wrote: [snip] > For the archives sake: This likely largely is the consequence of > building with LLVM's expensive assertions enabled, as confirmed by > Jonathan over IM. I recompiled with the release version of LLVM. jit=3Don was still slower, but the discrepancy was not as bad as the previously reported result: jit =3D off Planning Time: 0.938 ms Execution Time: 935.599 ms jit =3D on Planning Time: 0.951 ms JIT: =C2=A0 Functions: 184 =C2=A0 Generation Time: 17.605 ms =C2=A0 Inlining: true =C2=A0 Inlining Time: 20.522 ms =C2=A0 Optimization: true =C2=A0 Optimization Time: 1001.034 ms =C2=A0 Emission Time: 665.319 ms Execution Time: 2491.560 ms However, it was still 2x+ slower, so still +1ing for open items. =C2=A0 =C2=A0 I compiled with whatever switches LLVM=C2=A0that comes with=C2=A0Ubuntu 18.= 04=C2=A0is built=20 with, and without debugging or=C2=A0assertions. =C2=A0 -- Andreas Joseph Krogh ------=_Part_12_655446660.1535008496201 Content-Type: text/html;charset=UTF-8 Content-Transfer-Encoding: quoted-printable
P=C3=A5 torsdag 23. august 2018 kl. 03:00:42, skrev Jonathan S. Katz &= lt;jkatz@postgresql.org>:
> On Aug 22, 2018, at 7:13 PM, Andres Freund <andres@anarazel.de> = wrote:
[snip]
> For the archives sake: This likely largely is the consequence of
> building with LLVM's expensive assertions enabled, as confirmed by
> Jonathan over IM.

I recompiled with the release version of LLVM. jit=3Don was still slower, but the discrepancy was not as bad as the previously reported result:

jit =3D off
Planning Time: 0.938 ms
Execution Time: 935.599 ms

jit =3D on
Planning Time: 0.951 ms
JIT:
=C2=A0 Functions: 184
=C2=A0 Generation Time: 17.605 ms
=C2=A0 Inlining: true
=C2=A0 Inlining Time: 20.522 ms
=C2=A0 Optimization: true
=C2=A0 Optimization Time: 1001.034 ms
=C2=A0 Emission Time: 665.319 ms
Execution Time: 2491.560 ms

However, it was still 2x+ slower, so still +1ing for open items.
=C2=A0
=C2=A0
I compiled with whatever switches LLVM=C2=A0that comes with=C2=A0Ubunt= u 18.04=C2=A0is built with, and without debugging or=C2=A0assertions.
=C2=A0
">
--
Andreas Joseph Krogh
------=_Part_12_655446660.1535008496201-- ------=_Part_11_729917402.1535008496189-- ------=_Part_10_652420533.1535008496189--